==> ser_0.9.7.orig.tar.gz: ser-0.9.7/parser/case_www.h <==
/* 
 * $Id: case_www.h,v 1.5 2004/08/24 09:01:25 janakj Exp $ 
 *
 * WWW-Authenticate Header Field Name Parsing Macros
 *
 * Copyright (C) 2001-2003 FhG Fokus
 *
 * This file is part of ser, a free SIP server.
 *
 * ser is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * For a license to use the ser software under conditions
 * other than those described here, or to purchase support for this
 * software, please contact iptel.org by e-mail at the following addresses:
 *    info@iptel.org
 *
 * ser is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#ifndef CASE_WWW_H
#define CASE_WWW_H


#define CATE_CASE                        \
        switch(LOWER_DWORD(val)) {       \
        case _cate_:                     \
                hdr->type = HDR_WWWAUTH; \
                p += 4;                  \
	        goto dc_end;             \
        }


#define ENTI_CASE                  \
        switch(LOWER_DWORD(val)) { \
        case _enti_:               \
                p += 4;            \
                val = READ(p);     \
                CATE_CASE;         \
                goto other;        \
} 


#define WWW_AUTH_CASE              \
        switch(LOWER_DWORD(val)) { \
        case _auth_:               \
	        p += 4;            \
                val = READ(p);     \
                ENTI_CASE;         \
	        goto other;        \
        }


#define www_CASE          \
        p += 4;           \
        val = READ(p);    \
        WWW_AUTH_CASE;    \
        goto other;


#endif /* CASE_WWW_H */

==> ser_2.0.0.orig.tar.gz: ser-2.0.0/parser/case_www.h <==
/* 
 * $Id: case_www.h,v 1.7 2006/10/16 18:44:02 andrei Exp $ 
 *
 * WWW-Authenticate Header Field Name Parsing Macros
 *
 * Copyright (C) 2001-2003 FhG Fokus
 *
 * This file is part of ser, a free SIP server.
 *
 * ser is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * For a license to use the ser software under conditions
 * other than those described here, or to purchase support for this
 * software, please contact iptel.org by e-mail at the following addresses:
 *    info@iptel.org
 *
 * ser is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#ifndef CASE_WWW_H
#define CASE_WWW_H


#define CATE_CASE                        \
        switch(LOWER_DWORD(val)) {       \
        case _cate_:                     \
                hdr->type = HDR_WWW_AUTHENTICATE_T; \
                p += 4;                  \
	        goto dc_end;             \
        }


#define ENTI_CASE                  \
        switch(LOWER_DWORD(val)) { \
        case _enti_:               \
                p += 4;            \
                val = READ(p);     \
                CATE_CASE;         \
                goto other;        \
} 


#define WWW_AUTH_CASE              \
        switch(LOWER_DWORD(val)) { \
        case _auth_:               \
	        p += 4;            \
                val = READ(p);     \
                ENTI_CASE;         \
	        goto other;        \
        }


#define www_CASE          \
        p += 4;           \
        val = READ(p);    \
        WWW_AUTH_CASE;    \
        goto other;


#endif /* CASE_WWW_H */
